==> ejc-jlcost-impl-3.0.0-20240705.005552-198-sources.jar: com/ejianc/business/jlcost/payout/mapper/SettleMapper.java <==
package com.ejianc.business.jlcost.payout.mapper;

import com.ejianc.business.jlcost.payout.vo.ContractSettleResult;
import com.ejianc.business.jlcost.payout.vo.SettleVO;
import com.ejianc.business.jlcost.payout.vo.SjCostReportVO;
import org.apache.ibatis.annotations.Mapper;

import com.ejianc.framework.skeleton.template.BaseCrudMapper;
import com.ejianc.business.jlcost.payout.bean.SettleEntity;
import org.apache.ibatis.annotations.Param;

import java.math.BigDecimal;
import java.util.List;

import java.util.List;
import java.util.Map;

/**
 * 支出结算-主表
 * 
 * @author generator
 * 
 */
@Mapper
public interface SettleMapper extends BaseCrudMapper<SettleEntity> {

    List<SjCostReportVO> getWbsjMnyByProjectId(@Param("projectId") Long projectId);


    List<SjCostReportVO> getWbjcMnyByProjectId(@Param("projectId") Long projectId,@Param("productId") Long productId);

    List<SjCostReportVO> getWxjgMnyByProjectId(@Param("projectId") Long projectId,@Param("productId") Long productId);

    List<SjCostReportVO> getWbcpMnyByProjectId(@Param("projectId") Long projectId,@Param("productId") Long productId);

    List<SjCostReportVO> getCpcgMnyByProjectId(@Param("projectId") Long projectId,@Param("productId") Long productId);

    BigDecimal selectCertifiedMny(@Param("projectId") Long projectId,@Param("productId") Long productId);

    BigDecimal selectDetectionMny(@Param("projectId") Long projectId,@Param("productId") Long productId);

    List<ContractSettleResult> querySettleList();
}

==> ejc-jlcost-impl-3.0.0-20240823.002531-237-sources.jar: com/ejianc/business/jlcost/payout/mapper/SettleMapper.java <==
package com.ejianc.business.jlcost.payout.mapper;

import com.baomidou.mybatisplus.core.conditions.query.QueryWrapper;
import com.baomidou.mybatisplus.core.toolkit.Constants;
import com.baomidou.mybatisplus.extension.plugins.pagination.Page;
import com.ejianc.business.jlcost.payout.vo.ContractSettleResult;
import com.ejianc.business.jlcost.payout.vo.SettleVO;
import com.ejianc.business.jlcost.payout.vo.SjCostReportVO;
import org.apache.ibatis.annotations.Mapper;

import com.ejianc.framework.skeleton.template.BaseCrudMapper;
import com.ejianc.business.jlcost.payout.bean.SettleEntity;
import org.apache.ibatis.annotations.Param;

import java.math.BigDecimal;
import java.util.List;

import java.util.List;
import java.util.Map;

/**
 * 支出结算-主表
 * 
 * @author generator
 * 
 */
@Mapper
public interface SettleMapper extends BaseCrudMapper<SettleEntity> {

    List<SjCostReportVO> getWbsjMnyByProjectId(@Param("projectId") Long projectId);


    List<SjCostReportVO> getWbjcMnyByProjectId(@Param("projectId") Long projectId,@Param("productId") Long productId);

    List<SjCostReportVO> getWxjgMnyByProjectId(@Param("projectId") Long projectId,@Param("productId") Long productId);

    List<SjCostReportVO> getWbcpMnyByProjectId(@Param("projectId") Long projectId,@Param("productId") Long productId);

    List<SjCostReportVO> getCpcgMnyByProjectId(@Param("projectId") Long projectId,@Param("productId") Long productId);

    BigDecimal selectCertifiedMny(@Param("projectId") Long projectId,@Param("productId") Long productId);

    BigDecimal selectDetectionMny(@Param("projectId") Long projectId,@Param("productId") Long productId);

    List<SettleVO> querySettleOrgList(Page pages, @Param(Constants.WRAPPER) QueryWrapper queryWrapper, @Param("contractId") Long contractId);

    List<SettleVO> querySettleList(Page pages, @Param(Constants.WRAPPER) QueryWrapper queryWrapper, @Param("contractId") Long contractId,@Param("projectId") Long projectId,@Param("orgId") Long orgId);
}
